OC.L10N.register(
    "comments",
    {
    "Type in a new comment..." : "Ketik di komentar baru...",
    "Delete comment" : "Hapus komentar",
    "Post" : "Posting",
    "Cancel" : "Batal",
    "Edit comment" : "Sunting komentar",
    "[Deleted user]" : "[Hapus pengguna]",
    "Comments" : "Komentar",
    "No other comments available" : "Tidak ada komentar lainnya",
    "More comments..." : "Komentar lainya...",
    "Save" : "Simpan",
    "Allowed characters {count} of {max}" : "Karakter yang diizinkan {count} dari {max}",
    "Error occurred while retrieving comment with id {id}" : "Kesalahan terjadi saat mengambil komentar dengan id {id}.",
    "Error occurred while updating comment with id {id}" : "Kesalahan terjadi saat memperbarui komentar dengan id {id}.",
    "Error occurred while posting comment" : "Kesalahan terjadi saat mengirim komentar",
    "{count} unread comments" : "{count} komentar belum dibaca",
    "Comment" : "Komentar",
    "You commented" : "Anda berkomentar",
    "%1$s commented" : "%1$s dikomentari",
    "You commented on %2$s" : "Anda berkomentar pada %2$s",
    "%1$s commented on %2$s" : "%1$s dikomentari pada %2$s",
    "<strong>Comments</strong> for files <em>(always listed in stream)</em>" : "<strong> Komentar </strong> untuk berkas  (selalu terdapat di stream) </em>"
},
"nplurals=1; plural=0;");
